@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 1999 Peter Miller;
+ *	Copyright (C) 1998, 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -39,7 +39,7 @@
  * otherwise, provide a prototype and nothing else
  */
 #include <main.h>
-char *gettext _((const char *));
+char *gettext(const char *);
 #endif /* !HAVE_LIBGETTEXT_H */
 #endif /* !HAVE_LIBINTL_H */
 
