@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,7 @@
 #include <config.h>
 #ifndef HAVE_CUSERID
 #include <main.h>
-char *cuserid _((char *));
+char *cuserid(char *);
 #endif
 
 #endif /* COMMON_AC_STDIO_H */
