@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,16 +27,14 @@
 
 
 size_t
-wcslen(wcs)
-	const wchar_t	*wcs;
+wcslen(const wchar_t *wcs)
 {
-	const wchar_t	*start;
+    const wchar_t   *start;
 
-	start = wcs;
-	while (*wcs)
-		++wcs;
-	return (wcs - start);
+    start = wcs;
+    while (*wcs)
+	++wcs;
+    return (wcs - start);
 }
 
-
 #endif /* !HAVE_WCSLEN */
