@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void env_set _((char *name, char *value));
-void env_unset _((char *name));
+void env_set(char *name, char *value);
+void env_unset(char *name);
 
 #endif /* COMMON_ENV_H */
