@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,16 +21,17 @@
  */
 
 #include <ac/ctype.h>
+#include <ac/errno.h>
+#include <ac/stdarg.h>
 #include <ac/stddef.h>
 #include <ac/stdio.h>
-#include <ac/stdarg.h>
-#include <ac/string.h>
-#include <ac/errno.h>
 #include <ac/stdlib.h>
+#include <ac/string.h>
 
 #include <error.h>
 #include <mprintf.h>
 #include <progname.h>
+#include <quit.h>
 
 
 /*
@@ -50,11 +51,8 @@
 
 #define PAGE_WIDTH 79
 
-static void wrap _((char *));
-
 static void
-wrap(s)
-	char	*s;
+wrap(char *s)
 {
 	static char escapes[] = "\rr\nn\ff\bb\tt";
 	char	tmp[PAGE_WIDTH + 2];
@@ -181,7 +179,7 @@ wrap(s)
 	if (fflush(stderr) || ferror(stderr))
 	{
 		/* don't print why, there is no point! */
-		exit(1);
+		quit(1);
 	}
 	if (bomb_later)
 	{
@@ -191,10 +189,8 @@ wrap(s)
 }
 
 
-static void double_jeopardy _((void));
-
 static void
-double_jeopardy()
+double_jeopardy(void)
 {
 	char	buffer[200];
 
@@ -205,15 +201,12 @@ double_jeopardy()
 		strerror(errno)
 	);
 	wrap(buffer);
-	exit(1);
+	quit(1);
 }
 
 
-static char *copy_string _((char *));
-
 static char *
-copy_string(s)
-	char		*s;
+copy_string(char *s)
 {
 	char		*cp;
 
@@ -250,14 +243,12 @@ copy_string(s)
  */
 
 void
-error_raw(s sva_last)
-	char		*s;
-	sva_last_decl
+error_raw(char *s, ...)
 {
 	va_list		ap;
 	char		*buffer;
 
-	sva_init(ap, s);
+	va_start(ap, s);
 	buffer = vmprintf_errok(s, ap);
 	if (!buffer)
 		double_jeopardy();
@@ -287,9 +278,7 @@ error_raw(s sva_last)
  */
 
 void
-nerror_raw(s sva_last)
-	char		*s;
-	sva_last_decl
+nerror_raw(char *s, ...)
 {
 	va_list		ap;
 	int		n;
@@ -297,7 +286,7 @@ nerror_raw(s sva_last)
 	char		*buf2;
 
 	n = errno;
-	sva_init(ap, s);
+	va_start(ap, s);
 	buf1 = vmprintf_errok(s, ap);
 	if (!buf1)
 		double_jeopardy();
@@ -334,9 +323,7 @@ nerror_raw(s sva_last)
  */
 
 void
-nfatal_raw(s sva_last)
-	char		*s;
-	sva_last_decl
+nfatal_raw(char *s, ...)
 {
 	va_list		ap;
 	int		n;
@@ -344,7 +331,7 @@ nfatal_raw(s sva_last)
 	char		*buf2;
 
 	n = errno;
-	sva_init(ap, s);
+	va_start(ap, s);
 	buf1 = vmprintf_errok(s, ap);
 	if (!buf1)
 		double_jeopardy();
@@ -354,7 +341,7 @@ nfatal_raw(s sva_last)
 	if (!buf2)
 		double_jeopardy();
 	wrap(buf2);
-	exit(1);
+	quit(1);
 }
 
 
@@ -380,20 +367,18 @@ nfatal_raw(s sva_last)
  */
 
 void
-fatal_raw(s sva_last)
-	char		*s;
-	sva_last_decl
+fatal_raw(char *s, ...)
 {
 	va_list		ap;
 	char		*buffer;
 
-	sva_init(ap, s);
+	va_start(ap, s);
 	buffer = vmprintf_errok(s, ap);
 	if (!buffer)
 		double_jeopardy();
 	va_end(ap);
 	wrap(buffer);
-	exit(1);
+	quit(1);
 }
 
 
@@ -423,11 +408,7 @@ fatal_raw(s sva_last)
 #endif
 
 void
-my_assert(c, s, file, line)
-	int	c;
-	char	*s;
-	char	*file;
-	int	line;
+my_assert(int c, char *s, char *file, int line)
 {
 	if (c)
 		return;
