@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,13 +27,12 @@
 
 #include <main.h>
 
-FILE *fopen_and_check _((const char *, const char *));
-void fflush_and_check _((FILE *, const char *));
-void fclose_and_check _((FILE *, const char *));
-void warning_last_line_unterminated _((const char *));
+FILE *fopen_and_check(const char *, const char *);
+void fflush_and_check(FILE *, const char *);
+void fclose_and_check(FILE *, const char *);
+void warning_last_line_unterminated(const char *);
 
 struct sub_context_ty;
-void fatal_with_filename _((const char *, struct sub_context_ty *,
-	const char *));
+void fatal_with_filename(const char *, struct sub_context_ty *, const char *);
 
 #endif /* COMMON_FCHECK_H */
