@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -36,14 +36,14 @@
 /*
  * Function Prototypes
  */
-void seekf _((FILE *, long, const char *));
-int skipf _((FILE *, long, const char *));
-char *readlinef _((FILE *, long *, int, const char *, int *));
-long readf _((FILE *, char *, long, const char *, int *));
-void writefx _((FILE *, char *, long, const char *));
-int copyf _((FILE *, FILE *, long, const char *, const char *));
-void copyfx _((FILE *, FILE *, long, const char *, const char *));
-int typef _((FILE *, const char *));
-void typefx _((FILE *, const char *));
+void seekf(FILE *, long, const char *);
+int skipf(FILE *, long, const char *);
+char *readlinef(FILE *, long *, int, const char *, int *);
+long readf(FILE *, char *, long, const char *, int *);
+void writefx(FILE *, char *, long, const char *);
+int copyf(FILE *, FILE *, long, const char *, const char *);
+void copyfx(FILE *, FILE *, long, const char *, const char *);
+int typef(FILE *, const char *);
+void typefx(FILE *, const char *);
 
 #endif /* FILEIO_H */
