@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1995, 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,14 +30,13 @@
 #include <help.h>
 #include <libdir.h>
 #include <progname.h>
+#include <quit.h>
 #include <str_list.h>
 #include <trace.h>
 
 
-static void help_env _((void));
-
 static void
-help_env()
+help_env(void)
 {
 	char		*cp;
 	string_list_ty	manpath;
@@ -149,9 +148,7 @@ help_env()
 
 
 void
-help(progname, usage)
-	char		*progname;
-	void		(*usage)_((void));
+help(char *progname, void (*usage)(void))
 {
 	char		*argv[3];
 	sub_context_ty	*scp;
@@ -194,12 +191,11 @@ help(progname, usage)
 
 
 void
-bad_argument(usage)
-	void	(*usage)_((void));
+bad_argument(void (*usage)(void))
 {
 	sub_context_ty	*scp;
 
-	trace(("bad_argument()\n{\n"/*}*/));
+	trace(("bad_argument()\n{\n"));
 	switch (arglex_token)
 	{
 	case arglex_token_string:
@@ -235,7 +231,7 @@ bad_argument(usage)
 		break;
 	}
 	usage();
-	trace((/*{*/"}\n"));
-	exit(1);
+	trace(("}\n"));
+	quit(1);
 	/* NOTREACHED */
 }
