@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void help _((char *, void (*usage)(void)));
-void bad_argument _((void(*)(void)));
+void help(char *, void (*usage)(void));
+void bad_argument(void(*)(void));
 
 #endif /* HELP_H */
