@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <input.h>
 
-input_ty *input_crlf _((input_ty *, int));
+input_ty *input_crlf(input_ty *, int);
 
 #endif /* COMMON_INPUT_CRLF_H */
