@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 
 #include <input.h>
 
-input_ty *input_file_open _((const char *));
-void input_file_unlink_on_close _((input_ty *));
+input_ty *input_file_open(const char *);
+void input_file_unlink_on_close(input_ty *);
 
 #endif /* COMMON_INPUT_FILE_H */
