@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,37 +25,33 @@
 
 
 input_ty *
-input_new(vptr)
-	input_vtbl_ty	*vptr;
+input_new(input_vtbl_ty *vptr)
 {
-	input_ty	*result;
+    input_ty        *result;
 
-	result = mem_alloc(vptr->size);
-	result->vptr = vptr;
-	result->pushback_buf = 0;
-	result->pushback_len = 0;
-	result->pushback_max = 0;
-	return result;
+    result = mem_alloc(vptr->size);
+    result->vptr = vptr;
+    result->pushback_buf = 0;
+    result->pushback_len = 0;
+    result->pushback_max = 0;
+    return result;
 }
 
 
 long
-input_generic_read(fp, data_v, len)
-	input_ty	*fp;
-	void		*data_v;
-	long		len;
+input_generic_read(input_ty *fp, void *data_v, long len)
 {
-	char		*data;
-	long		result;
-	int		c;
+    char            *data;
+    long            result;
+    int             c;
 
-	data = data_v;
-	for (result = 0; result < len; ++result)
-	{
-		c = fp->vptr->get(fp);
-		if (c < 0)
-			break;
-		*data++ = c;
-	}
-	return result;
+    data = data_v;
+    for (result = 0; result < len; ++result)
+    {
+	c = fp->vptr->get(fp);
+	if (c < 0)
+    	    break;
+	*data++ = c;
+    }
+    return result;
 }
