@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,12 +32,11 @@
  */
 
 int
-isdir(pathname)
-	const char	*pathname;
+isdir(const char *pathname)
 {
-	struct stat	buf;
+    struct stat     buf;
 
-	if (stat(pathname, &buf) < 0)
-		return 0;
-	return S_ISDIR(buf.st_mode);
+    if (stat(pathname, &buf) < 0)
+       	return 0;
+    return S_ISDIR(buf.st_mode);
 }
