@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,21 +25,21 @@
 
 
 char *
-library_directory_get()
+library_directory_get(void)
 {
-	return LIBDIR;
+    return LIBDIR;
 }
 
 
 char *
-data_directory_get()
+data_directory_get(void)
 {
-	return DATADIR;
+    return DATADIR;
 }
 
 
 char *
-manual_directory_get()
+manual_directory_get(void)
 {
-	return MANDIR;
+    return MANDIR;
 }
