@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 2000 Peter Miller;
+ *	Copyright (C) 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,12 +25,12 @@
 
 #include <output.h>
 
-output_ty *output_new _((output_vtbl_ty *));
-long output_generic_ftell _((output_ty *));
-void output_generic_fputs _((output_ty *, const char *));
-void output_generic_write _((output_ty *, const void *, size_t));
-void output_generic_flush _((output_ty *));
-int output_generic_page_width _((output_ty *));
-int output_generic_page_length _((output_ty *));
+output_ty *output_new(output_vtbl_ty *);
+long output_generic_ftell(output_ty *);
+void output_generic_fputs(output_ty *, const char *);
+void output_generic_write(output_ty *, const void *, size_t);
+void output_generic_flush(output_ty *);
+int output_generic_page_width(output_ty *);
+int output_generic_page_length(output_ty *);
 
 #endif /* LIBAEGIS_OUTPUT_PRIVATE_H */
