@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1992-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -47,8 +47,7 @@ static	int	pid;
 #include <sys/termio.h>
 
 int
-tcgetpgrp(fd)
-	int		fd;
+tcgetpgrp(int fd)
 {
 	int		result;
 
@@ -90,12 +89,10 @@ tcgetpgrp(fd)
  *	If you need to modify this function, please let the author know.
  */
 
-static int background _((void));
-
 static int
-background()
+background(void)
 {
-	RETSIGTYPE	(*x)_((int));
+	RETSIGTYPE	(*x)(int);
 
 	/*
 	 * C shell
@@ -125,11 +122,8 @@ background()
 }
 
 
-static FILE *pipe_open _((char *));
-
 static FILE *
-pipe_open(prog)
-	char		*prog;
+pipe_open(char *prog)
 {
 	FILE		*fp;
 	int		fd[2];
@@ -192,11 +186,8 @@ pipe_open(prog)
 }
 
 
-static void pipe_close _((FILE *));
-
 static void
-pipe_close(fp)
-	FILE		*fp;
+pipe_close(FILE *fp)
 {
 	int		status;
 	int		n;
@@ -214,10 +205,8 @@ pipe_close(fp)
 
 #ifdef HAVE_ATEXIT
 
-static void cleanup _((void));
-
 static void
-cleanup()
+cleanup(void)
 {
 	if (!out)
 		return;
@@ -242,7 +231,7 @@ cleanup()
 
 
 FILE *
-pager_open()
+pager_open(void)
 {
 	/* assert(!out); */
 
@@ -285,8 +274,7 @@ pager_open()
 
 
 void
-pager_close(fp)
-	FILE		*fp;
+pager_close(FILE *fp)
 {
 	/* assert(out); */
 	/* assert(fp == out); */
@@ -311,8 +299,7 @@ pager_close(fp)
 
 
 void
-pager_error(fp)
-	FILE		*fp;
+pager_error(FILE *fp)
 {
 	sub_context_ty	*scp;
 
