@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1992, 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1992-1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,8 @@
 #include <ac/stdio.h>
 #include <main.h>
 
-FILE *pager_open _((void));
-void pager_close _((FILE *));
-void pager_error _((FILE *));
+FILE *pager_open(void);
+void pager_close(FILE *);
+void pager_error(FILE *);
 
 #endif /* PAGER_H */
