@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void progname_set _((char *));
-char *progname_get _((void));
+void progname_set(char *);
+char *progname_get(void);
 
 #endif /* COMMON_PROGNAME_H */
