@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2001 Peter Miller;
+ *	Copyright (C) 1998, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,21 +49,19 @@
  */
 
 void
-string_list_append(wlp, w)
-	string_list_ty	*wlp;
-	string_ty	*w;
+string_list_append(string_list_ty *wlp, string_ty *w)
 {
-	/* assert(wlp); */
-	/* assert(w); */
-	if (wlp->nstrings >= wlp->nstrings_max)
-	{
-		size_t		nbytes;
+    /* assert(wlp); */
+    /* assert(w); */
+    if (wlp->nstrings >= wlp->nstrings_max)
+    {
+	size_t		nbytes;
 
-		wlp->nstrings_max = wlp->nstrings_max * 2 + 16;
-		nbytes = wlp->nstrings_max * sizeof(string_ty *);
-		wlp->string = mem_change_size(wlp->string, nbytes);
-	}
-	wlp->string[wlp->nstrings++] = str_copy(w);
+	wlp->nstrings_max = wlp->nstrings_max * 2 + 16;
+	nbytes = wlp->nstrings_max * sizeof(string_ty *);
+	wlp->string = mem_change_size(wlp->string, nbytes);
+    }
+    wlp->string[wlp->nstrings++] = str_copy(w);
 }
 
 
@@ -80,14 +78,12 @@ string_list_append(wlp, w)
  */
 
 void
-string_list_append_list(to, from)
-	string_list_ty	*to;
-	const string_list_ty *from;
+string_list_append_list(string_list_ty *to, const string_list_ty *from)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < from->nstrings; ++j)
-		string_list_append(to, from->string[j]);
+    for (j = 0; j < from->nstrings; ++j)
+       	string_list_append(to, from->string[j]);
 }
 
 
@@ -104,26 +100,24 @@ string_list_append_list(to, from)
  */
 
 void
-string_list_prepend(wlp, w)
-	string_list_ty	*wlp;
-	string_ty	*w;
+string_list_prepend(string_list_ty *wlp, string_ty *w)
 {
-	ptrdiff_t	j;
+    ptrdiff_t       j;
 
-	/* assert(wlp); */
-	/* assert(w); */
-	if (wlp->nstrings >= wlp->nstrings_max)
-	{
-		size_t		nbytes;
+    /* assert(wlp); */
+    /* assert(w); */
+    if (wlp->nstrings >= wlp->nstrings_max)
+    {
+	size_t		nbytes;
 
-		wlp->nstrings_max = wlp->nstrings_max * 2 + 16;
-		nbytes = wlp->nstrings_max * sizeof(string_ty *);
-		wlp->string = mem_change_size(wlp->string, nbytes);
-	}
-	wlp->nstrings++;
-	for (j = wlp->nstrings - 1; j > 0; --j)
-		wlp->string[j] = wlp->string[j - 1];
-	wlp->string[0] = str_copy(w);
+	wlp->nstrings_max = wlp->nstrings_max * 2 + 16;
+	nbytes = wlp->nstrings_max * sizeof(string_ty *);
+	wlp->string = mem_change_size(wlp->string, nbytes);
+    }
+    wlp->nstrings++;
+    for (j = wlp->nstrings - 1; j > 0; --j)
+	wlp->string[j] = wlp->string[j - 1];
+    wlp->string[0] = str_copy(w);
 }
 
 
@@ -144,18 +138,17 @@ string_list_prepend(wlp, w)
  */
 
 void
-string_list_destructor(wlp)
-	string_list_ty	*wlp;
+string_list_destructor(string_list_ty *wlp)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < wlp->nstrings; j++)
-		str_free(wlp->string[j]);
-	if (wlp->string)
-		mem_free(wlp->string);
-	wlp->nstrings = 0;
-	wlp->nstrings_max = 0;
-	wlp->string = 0;
+    for (j = 0; j < wlp->nstrings; j++)
+	str_free(wlp->string[j]);
+    if (wlp->string)
+	mem_free(wlp->string);
+    wlp->nstrings = 0;
+    wlp->nstrings_max = 0;
+    wlp->string = 0;
 }
 
 
@@ -176,16 +169,14 @@ string_list_destructor(wlp)
  */
 
 int
-string_list_member(wlp, w)
-	const string_list_ty *wlp;
-	string_ty	*w;
+string_list_member(const string_list_ty *wlp, string_ty *w)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < wlp->nstrings; j++)
-		if (str_equal(wlp->string[j], w))
-			return 1;
-	return 0;
+    for (j = 0; j < wlp->nstrings; j++)
+	if (str_equal(wlp->string[j], w))
+    	    return 1;
+    return 0;
 }
 
 
@@ -206,25 +197,23 @@ string_list_member(wlp, w)
  */
 
 int
-string_list_intersect(wl1, wl2)
-	const string_list_ty *wl1;
-	const string_list_ty *wl2;
+string_list_intersect(const string_list_ty *wl1, const string_list_ty *wl2)
 {
-	size_t		j;
+    size_t          j;
 
-	if (wl1->nstrings > wl2->nstrings)
-	{
-		for (j = 0; j < wl2->nstrings; j++)
-			if (string_list_member(wl1, wl2->string[j]))
-				return 1;
-	}
-	else
-	{
-		for (j = 0; j < wl1->nstrings; j++)
-			if (string_list_member(wl2, wl1->string[j]))
-				return 1;
-	}
-	return 0;
+    if (wl1->nstrings > wl2->nstrings)
+    {
+	for (j = 0; j < wl2->nstrings; j++)
+    	    if (string_list_member(wl1, wl2->string[j]))
+       		return 1;
+    }
+    else
+    {
+	for (j = 0; j < wl1->nstrings; j++)
+    	    if (string_list_member(wl2, wl1->string[j]))
+       		return 1;
+    }
+    return 0;
 }
 
 
@@ -247,15 +236,13 @@ string_list_intersect(wl1, wl2)
  */
 
 void
-string_list_copy_constructor(to, from)
-	string_list_ty	*to;
-	const string_list_ty *from;
+string_list_copy_constructor(string_list_ty *to, const string_list_ty *from)
 {
-	size_t		j;
+    size_t          j;
 
-	string_list_constructor(to);
-	for (j = 0; j < from->nstrings; j++)
-		string_list_append(to, str_copy(from->string[j]));
+    string_list_constructor(to);
+    for (j = 0; j < from->nstrings; j++)
+       	string_list_append(to, str_copy(from->string[j]));
 }
 
 
@@ -278,59 +265,55 @@ string_list_copy_constructor(to, from)
  */
 
 string_ty *
-wl2str(wl, start, stop, sep)
-	const string_list_ty *wl;
-	int		start;
-	int		stop;
-	char		*sep;
+wl2str(const string_list_ty *wl, int start, int stop, char *sep)
 {
-	int		j;
-	static char	*tmp;
-	static size_t	tmplen;
-	size_t		length;
-	size_t		seplen;
-	char		*pos;
-	string_ty	*s;
+    int             j;
+    static char     *tmp;
+    static size_t   tmplen;
+    size_t          length;
+    size_t          seplen;
+    char            *pos;
+    string_ty       *s;
 
-	if (!sep)
-		sep = " ";
-	seplen = strlen(sep);
-	length = 0;
-	for (j = start; j <= stop && j < wl->nstrings; j++)
+    if (!sep)
+	sep = " ";
+    seplen = strlen(sep);
+    length = 0;
+    for (j = start; j <= stop && j < wl->nstrings; j++)
+    {
+	s = wl->string[j];
+	if (s->str_length)
 	{
-		s = wl->string[j];
-		if (s->str_length)
-		{
-			if (length)
-				length += seplen;
-			length += s->str_length;
-		}
+	    if (length)
+	       	length += seplen;
+	    length += s->str_length;
 	}
+    }
 
-	if (tmplen < length)
+    if (tmplen < length)
+    {
+	tmplen = length;
+	tmp = mem_change_size(tmp, tmplen);
+    }
+
+    pos = tmp;
+    for (j = start; j <= stop && j < wl->nstrings; j++)
+    {
+	s = wl->string[j];
+	if (s->str_length)
 	{
-		tmplen = length;
-		tmp = mem_change_size(tmp, tmplen);
+    	    if (pos != tmp)
+    	    {
+		memcpy(pos, sep, seplen);
+       		pos += seplen;
+    	    }
+    	    memcpy(pos, s->str_text, s->str_length);
+    	    pos += s->str_length;
 	}
+    }
 
-	pos = tmp;
-	for (j = start; j <= stop && j < wl->nstrings; j++)
-	{
-		s = wl->string[j];
-		if (s->str_length)
-		{
-			if (pos != tmp)
-			{
-				memcpy(pos, sep, seplen);
-				pos += seplen;
-			}
-			memcpy(pos, s->str_text, s->str_length);
-			pos += s->str_length;
-		}
-	}
-
-	s = str_n_from_c(tmp, length);
-	return s;
+    s = str_n_from_c(tmp, length);
+    return s;
 }
 
 
@@ -357,53 +340,49 @@ wl2str(wl, start, stop, sep)
  */
 
 void
-str2wl(slp, s, sep, ewhite)
-	string_list_ty	*slp;
-	string_ty	*s;
-	char		*sep;
-	int		ewhite;
+str2wl(string_list_ty *slp, string_ty *s, char *sep, int ewhite)
 {
-	char		*cp;
-	int		more;
+    char            *cp;
+    int             more;
 
-	if (!sep)
-	{
-		sep = " \t\n\f\r";
-		ewhite = 1;
-	}
-	string_list_constructor(slp);
-	cp = s->str_text;
+    if (!sep)
+    {
+	sep = " \t\n\f\r";
+	ewhite = 1;
+    }
+    string_list_constructor(slp);
+    cp = s->str_text;
+    more = 0;
+    while (*cp || more)
+    {
+	string_ty	*w;
+	char		*cp1;
+	char		*cp2;
+
+	if (ewhite)
+	    while (isspace((unsigned char)*cp))
+	       	cp++;
+	if (!*cp && !more)
+	    break;
 	more = 0;
-	while (*cp || more)
+	cp1 = cp;
+	while (*cp && !strchr(sep, *cp))
+	    cp++;
+	if (*cp)
 	{
-		string_ty	*w;
-		char		*cp1;
-		char		*cp2;
-
-		if (ewhite)
-			while (isspace((unsigned char)*cp))
-				cp++;
-		if (!*cp && !more)
-			break;
-		more = 0;
-		cp1 = cp;
-		while (*cp && !strchr(sep, *cp))
-			cp++;
-		if (*cp)
-		{
-			cp2 = cp + 1;
-			more = 1;
-		}
-		else
-			cp2 = cp;
-		if (ewhite)
-			while (cp > cp1 && isspace((unsigned char)cp[-1]))
-				cp--;
-		w = str_n_from_c(cp1, cp - cp1);
-		string_list_append(slp, w);
-		str_free(w);
-		cp = cp2;
+	    cp2 = cp + 1;
+	    more = 1;
 	}
+	else
+	    cp2 = cp;
+	if (ewhite)
+	    while (cp > cp1 && isspace((unsigned char)cp[-1]))
+	       	cp--;
+	w = str_n_from_c(cp1, cp - cp1);
+	string_list_append(slp, w);
+	str_free(w);
+	cp = cp2;
+    }
 }
 
 
@@ -423,16 +402,14 @@ str2wl(slp, s, sep, ewhite)
  */
 
 void
-string_list_append_unique(wlp, wp)
-	string_list_ty	*wlp;
-	string_ty	*wp;
+string_list_append_unique(string_list_ty *wlp, string_ty *wp)
 {
-	int		j;
+    size_t          j;
 
-	for (j = 0; j < wlp->nstrings; j++)
-		if (str_equal(wlp->string[j], wp))
-			return;
-	string_list_append(wlp, wp);
+    for (j = 0; j < wlp->nstrings; j++)
+       	if (str_equal(wlp->string[j], wp))
+	    return;
+    string_list_append(wlp, wp);
 }
 
 
@@ -451,14 +428,12 @@ string_list_append_unique(wlp, wp)
  */
 
 void
-string_list_append_list_unique(to, from)
-	string_list_ty	*to;
-	const string_list_ty *from;
+string_list_append_list_unique(string_list_ty *to, const string_list_ty *from)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < from->nstrings; ++j)
-		string_list_append_unique(to, from->string[j]);
+    for (j = 0; j < from->nstrings; ++j)
+       	string_list_append_unique(to, from->string[j]);
 }
 
 
@@ -477,24 +452,22 @@ string_list_append_list_unique(to, from)
  */
 
 void
-string_list_remove(wlp, wp)
-	string_list_ty	*wlp;
-	string_ty	*wp;
+string_list_remove(string_list_ty *wlp, string_ty *wp)
 {
-	size_t		j;
-	size_t		k;
+    size_t          j;
+    size_t          k;
 
-	for (j = 0; j < wlp->nstrings; ++j)
+    for (j = 0; j < wlp->nstrings; ++j)
+    {
+	if (str_equal(wlp->string[j], wp))
 	{
-		if (str_equal(wlp->string[j], wp))
-		{
-			wlp->nstrings--;
-			for (k = j; k < wlp->nstrings; ++k)
-				wlp->string[k] = wlp->string[k + 1];
-			str_free(wp);
-			break;
-		}
+	    wlp->nstrings--;
+	    for (k = j; k < wlp->nstrings; ++k)
+		wlp->string[k] = wlp->string[k + 1];
+	    str_free(wp);
+	    break;
 	}
+    }
 }
 
 
@@ -514,14 +487,12 @@ string_list_remove(wlp, wp)
  */
 
 void
-string_list_remove_list(wlp, nuke)
-	string_list_ty	*wlp;
-	const string_list_ty *nuke;
+string_list_remove_list(string_list_ty *wlp, const string_list_ty *nuke)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < nuke->nstrings; ++j)
-		string_list_remove(wlp, nuke->string[j]);
+    for (j = 0; j < nuke->nstrings; ++j)
+       	string_list_remove(wlp, nuke->string[j]);
 }
 
 
@@ -542,12 +513,11 @@ string_list_remove_list(wlp, nuke)
  */
 
 void
-string_list_constructor(wlp)
-	string_list_ty	*wlp;
+string_list_constructor(string_list_ty *wlp)
 {
-	wlp->nstrings = 0;
-	wlp->nstrings_max = 0;
-	wlp->string = 0;
+    wlp->nstrings = 0;
+    wlp->nstrings_max = 0;
+    wlp->string = 0;
 }
 
 
@@ -570,13 +540,13 @@ string_list_constructor(wlp)
  */
 
 string_list_ty *
-string_list_new()
+string_list_new(void)
 {
-	string_list_ty	*slp;
+    string_list_ty  *slp;
 
-	slp = mem_alloc(sizeof(string_list_ty));
-	string_list_constructor(slp);
-	return slp;
+    slp = mem_alloc(sizeof(string_list_ty));
+    string_list_constructor(slp);
+    return slp;
 }
 
 
@@ -599,14 +569,13 @@ string_list_new()
  */
 
 string_list_ty *
-string_list_new_copy(from)
-	const string_list_ty *from;
+string_list_new_copy(const string_list_ty *from)
 {
-	string_list_ty	*slp;
+    string_list_ty  *slp;
 
-	slp = mem_alloc(sizeof(string_list_ty));
-	string_list_copy_constructor(slp, from);
-	return slp;
+    slp = mem_alloc(sizeof(string_list_ty));
+    string_list_copy_constructor(slp, from);
+    return slp;
 }
 
 
@@ -623,11 +592,10 @@ string_list_new_copy(from)
  */
 
 void
-string_list_delete(slp)
-	string_list_ty	*slp;
+string_list_delete(string_list_ty *slp)
 {
-	string_list_destructor(slp);
-	mem_free(slp);
+    string_list_destructor(slp);
+    mem_free(slp);
 }
 
 
@@ -645,13 +613,12 @@ string_list_delete(slp)
  */
 
 int
-string_list_bool(slp)
-	const string_list_ty *slp;
+string_list_bool(const string_list_ty *slp)
 {
-	size_t		j;
+    size_t          j;
 
-	for (j = 0; j < slp->nstrings; ++j)
-		if (str_bool(slp->string[j]))
-			return 1;
-	return 0;
+    for (j = 0; j < slp->nstrings; ++j)
+	if (str_bool(slp->string[j]))
+    	    return 1;
+    return 0;
 }
