@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <sub.h>
 
-void sub_context_error_set _((sub_context_ty *, char *));
-int sub_context_errno_get _((sub_context_ty *));
+void sub_context_error_set(sub_context_ty *, char *);
+int sub_context_errno_get(sub_context_ty *);
 
 #endif /* COMMON_SUB_PRIVATE_H */
