@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -51,14 +51,11 @@ static	int		page_width;
 static	known_ty	*known;
 
 
-static string_ty *base_name _((char *));
-
 static string_ty *
-base_name(file)
-	char		*file;
+base_name(const char *file)
 {
-	char		*cp1;
-	char		*cp2;
+	const char	*cp1;
+	const char	*cp2;
 
 	cp1 = strrchr(file, '/');
 	if (cp1)
@@ -75,9 +72,7 @@ base_name(file)
 
 
 int
-trace_pretest(file, result)
-	char		*file;
-	int		*result;
+trace_pretest(const char *file, int *result)
 {
 	string_ty	*s;
 	known_ty	*kp;
@@ -109,9 +104,7 @@ trace_pretest(file, result)
 
 
 void
-trace_where(file, line)
-	char		*file;
-	int		line;
+trace_where(const char *file, int line)
 {
 	string_ty	*s;
 	int		err;
@@ -130,11 +123,8 @@ trace_where(file, line)
 }
 
 
-static void trace_putchar _((int));
-
 static void
-trace_putchar(c)
-	int		c;
+trace_putchar(int c)
 {
 	static int	depth;
 	static char	buffer[PAGE_WIDTH + 2];
@@ -233,16 +223,14 @@ trace_putchar(c)
 
 
 void
-trace_printf(s sva_last)
-	char		*s;
-	sva_last_decl
+trace_printf(const char *s, ...)
 {
 	string_ty	*buffer;
 	va_list		ap;
 	int		err;
 
 	err = errno;
-	sva_init(ap, s);
+	va_start(ap, s);
 	buffer = str_vformat(s, ap);
 	va_end(ap);
 	for (s = buffer->str_text; *s; ++s)
@@ -253,8 +241,7 @@ trace_printf(s sva_last)
 
 
 void
-trace_enable(file)
-	char		*file;
+trace_enable(const char *file)
 {
 	string_ty	*s;
 	known_ty	*kp;
@@ -290,9 +277,7 @@ trace_enable(file)
 
 
 void
-trace_char_real(name, vp)
-	char		*name;
-	char		*vp;
+trace_char_real(const char *name, const char *vp)
 {
 	trace_printf("%s = '", name);
 	if (*vp < ' ' || *vp > '~' || strchr("(){}[]", *vp))
@@ -319,9 +304,7 @@ trace_char_real(name, vp)
 
 
 void
-trace_char_unsigned_real(name, vp)
-	char		*name;
-	unsigned char	*vp;
+trace_char_unsigned_real(const char *name, const unsigned char *vp)
 {
 	trace_printf("%s = '", name);
 	if (*vp < ' ' || *vp > '~' || strchr("(){}[]", *vp))
@@ -348,48 +331,38 @@ trace_char_unsigned_real(name, vp)
 
 
 void
-trace_int_real(name, vp)
-	char		*name;
-	int		*vp;
+trace_int_real(const char *name, const int *vp)
 {
 	trace_printf("%s = %d;\n", name, *vp);
 }
 
 
 void
-trace_int_unsigned_real(name, vp)
-	char		*name;
-	unsigned int	*vp;
+trace_int_unsigned_real(const char *name, const unsigned int *vp)
 {
 	trace_printf("%s = %u;\n", name, *vp);
 }
 
 
 void
-trace_long_real(name, vp)
-	char		*name;
-	long		*vp;
+trace_long_real(const char *name, const long *vp)
 {
 	trace_printf("%s = %ld;\n", name, *vp);
 }
 
 
 void
-trace_long_unsigned_real(name, vp)
-	char		*name;
-	unsigned long	*vp;
+trace_long_unsigned_real(const char *name, const unsigned long *vp)
 {
 	trace_printf("%s = %lu;\n", name, *vp);
 }
 
 
 void
-trace_pointer_real(name, vptrptr)
-	char		*name;
-	void		*vptrptr;
+trace_pointer_real(const char *name, const void *vptrptr)
 {
-	void		**ptr_ptr = vptrptr;
-	void		*ptr;
+	const void *const *ptr_ptr = vptrptr;
+	const void	*ptr;
 
 	ptr = *ptr_ptr;
 	if (!ptr)
@@ -400,29 +373,23 @@ trace_pointer_real(name, vptrptr)
 
 
 void
-trace_short_real(name, vp)
-	char		*name;
-	short		*vp;
+trace_short_real(const char *name, const short *vp)
 {
 	trace_printf("%s = %hd;\n", name, *vp);
 }
 
 
 void
-trace_short_unsigned_real(name, vp)
-	char		*name;
-	unsigned short	*vp;
+trace_short_unsigned_real(const char *name, const unsigned short *vp)
 {
 	trace_printf("%s = %hu;\n", name, *vp);
 }
 
 
 void
-trace_string_real(name, vp)
-	char		*name;
-	char		*vp;
+trace_string_real(const char *name, const char *vp)
 {
-	char		*s;
+	const char	*s;
 	long		count;
 
 	trace_printf("%s = ", name);
