@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2000 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,26 +38,26 @@ struct wstring_ty
 	wchar_t		wstr_text[1];
 };
 
-wstring_ty *wstr_from_c _((const char *));
-wstring_ty *wstr_from_wc _((const wchar_t *));
-wstring_ty *wstr_n_from_c _((const char *, size_t));
-wstring_ty *wstr_n_from_wc _((const wchar_t *, size_t));
-wstring_ty *wstr_copy _((wstring_ty *));
-void wstr_free _((wstring_ty *));
-wstring_ty *wstr_catenate _((wstring_ty *, wstring_ty *));
-wstring_ty *wstr_cat_three _((wstring_ty *, wstring_ty *, wstring_ty *));
-wstring_ty *wstr_to_upper _((const wstring_ty *));
-wstring_ty *wstr_to_lower _((const wstring_ty *));
-wstring_ty *wstr_to_ident _((const wstring_ty *));
-void wstr_to_mbs _((wstring_ty *, char **, size_t *));
-int wstr_equal _((wstring_ty *, wstring_ty *));
+wstring_ty *wstr_from_c(const char *);
+wstring_ty *wstr_from_wc(const wchar_t *);
+wstring_ty *wstr_n_from_c(const char *, size_t);
+wstring_ty *wstr_n_from_wc(const wchar_t *, size_t);
+wstring_ty *wstr_copy(wstring_ty *);
+void wstr_free(wstring_ty *);
+wstring_ty *wstr_catenate(wstring_ty *, wstring_ty *);
+wstring_ty *wstr_cat_three(wstring_ty *, wstring_ty *, wstring_ty *);
+wstring_ty *wstr_to_upper(const wstring_ty *);
+wstring_ty *wstr_to_lower(const wstring_ty *);
+wstring_ty *wstr_to_ident(const wstring_ty *);
+void wstr_to_mbs(wstring_ty *, char **, size_t *);
+int wstr_equal(wstring_ty *, wstring_ty *);
 
 #ifndef DEBUG
 #define wstr_equal(s1, s2) ((s1) == (s2))
 #endif
 
 struct string_ty;
-struct string_ty *wstr_to_str _((wstring_ty *));
-wstring_ty *str_to_wstr _((struct string_ty *));
+struct string_ty *wstr_to_str(wstring_ty *);
+wstring_ty *str_to_wstr(struct string_ty *);
 
 #endif /* COMMON_WSTR_H */
