@@ -50,7 +50,11 @@ case $file in
 	echo "${stem}.gen.c ${stem}.gen.h: $file"
 	echo "	@echo Expect $numconf conflicts:"
 	echo "	\$(YACC) -d $file"
-	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e '/#include.<stdio.h>/d' y.tab.c > ${stem}.gen.c"
+	echo "	sed -e 's/[yY][yY]/${yy}_/g'" \
+		"-e '/#include.<stdio.h>/d'" \
+		"-e '/#include.<stdlib.h>/d'" \
+		"-e '/#include.<stddef.h>/d'" \
+		"y.tab.c > ${stem}.gen.c"
 	echo "	sed -e 's/[yY][yY]/${yy}_/g' y.tab.h > ${stem}.gen.h"
 	echo "	rm y.tab.c y.tab.h"
 
