@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -38,6 +38,7 @@
 #include <help.h>
 #include <isdir.h>
 #include <progname.h>
+#include <quit.h>
 #include <sub.h>
 #include <version.h>
 
@@ -86,10 +87,8 @@ static arglex_table_ty argtab[] =
  * Type out the possible commands.
  */
 
-static void usage _((void));
-
 static void
-usage()
+usage(void)
 {
 	char		*progname;
 
@@ -97,7 +96,7 @@ usage()
 	fprintf(stderr, "usage: %s [ <option>... ] <fileA> <fileB>\n", progname);
 	fprintf(stderr, "       %s -Help\n", progname);
 	fprintf(stderr, "       %s -VERSion\n", progname);
-	exit(1);
+	quit(1);
 }
 
 
@@ -105,10 +104,8 @@ usage()
  * give the user some help
  */
 
-static void main_help _((void));
-
 static void
-main_help()
+main_help(void)
 {
 	help(NULL, usage);
 }
@@ -120,11 +117,8 @@ main_help()
  * or returns copied value of global variable.
  */
 
-static char *expand _((char *));
-
 static char *
-expand(cp)
-	char	*cp;		/* string to be checked */
+expand(char *cp)
 {
 	char	*var;		/* variable value */
 
@@ -146,12 +140,8 @@ expand(cp)
  * results in "/etc/bar".
  */
 
-static char *dirfile _((char *, char *));
-
 static char *
-dirfile(dir_name, filename)
-	char	*dir_name;		/* name which is a directory */
-	char	*filename;		/* name which is a file name */
+dirfile(char *dir_name, char *filename)
 {
 	char	*cp;
 	char	*endname;
@@ -174,12 +164,8 @@ dirfile(dir_name, filename)
  * to be loaded with other programs and called by them easily.
  */
 
-int main _((int, char **));
-
 int
-main(argc, argv)
-	int		argc;
-	char		**argv;
+main(int argc, char **argv)
 {
 	char		*cp;
 	char		*nameA;
@@ -194,11 +180,11 @@ main(argc, argv)
 	{
 	case arglex_token_help:
 		main_help();
-		exit(0);
+		quit(0);
 
 	case arglex_token_version:
 		version();
-		exit(0);
+		quit(0);
 
 	default:
 		break;
@@ -480,6 +466,6 @@ main(argc, argv)
 		dumplines(ofile);
 	else
 		dumpnormal(ofile);
-	exit(0);
+	quit(0);
 	return 0;
 }
