@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,10 +25,10 @@
 
 #include <main.h>
 
-void diffhistory _((char *inputname, char *outputname, char *editname1,
-	char *editname2, int matchblab));
-void cleanhistory _((char *filename));
-void checkhistory _((char *filename));
-void comphistory _((char *filename));
+void diffhistory(char *inputname, char *outputname, char *editname1,
+	char *editname2, int matchblab);
+void cleanhistory(char *filename);
+void checkhistory(char *filename);
+void comphistory(char *filename);
 
 #endif /* DIFF_H */
