@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998-2001 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -83,12 +83,8 @@ static char fromsource;		/* dummy addr to indicate source file lines */
  * Initialize an edit list.
  */
 
-static void initlist _((EDIT *hp, EDIT *tp));
-
 static void
-initlist(hp, tp)
-	EDIT	*hp;		/* head of list */
-	EDIT	*tp;		/* tail of list */
+initlist(EDIT *hp, EDIT *tp)
 {
 	hp->e_count = 0;
 	hp->e_textlen = 0;
@@ -109,11 +105,8 @@ initlist(hp, tp)
  * specified edit structure in a list.
  */
 
-static EDIT *allocedit _((EDIT *ep));
-
 static EDIT *
-allocedit(ep)
-	EDIT	*ep;		/* edit element to insert in front of */
+allocedit(EDIT *ep)
 {
 	EDIT	*np;		/* new edit structure */
 
@@ -145,15 +138,8 @@ allocedit(ep)
  * Append a change to the new edit list.
  */
 
-static void addtolist _((FILE *fp, long line, long insertcount,
-	long deletecount));
-
 static void
-addtolist(fp, line, insertcount, deletecount)
-	FILE	*fp;		/* edit history file */
-	long	line;
-	long	insertcount;
-	long	deletecount;
+addtolist(FILE *fp, long line, long insertcount, long deletecount)
 {
 	EDIT	*ep;		/* pointer to current element structure */
 
@@ -183,12 +169,8 @@ addtolist(fp, line, insertcount, deletecount)
 }
 
 
-static void printone _((char *str, EDIT *ep));
-
 static void
-printone(str, ep)
-	char	*str;
-	EDIT	*ep;
+printone(const char *str, EDIT *ep)
 {
 	char	*blab;
 
@@ -213,12 +195,8 @@ printone(str, ep)
  * Print out an edit list
  */
 
-static void printlist _((char *msg, EDIT *ep));
-
 static void
-printlist(msg, ep)
-	char	*msg;
-	EDIT	*ep;
+printlist(const  char *msg, EDIT *ep)
 {
 	long	line;
 	char	*blab;
@@ -253,11 +231,8 @@ printlist(msg, ep)
  * Returns the next edit structure on the list.
  */
 
-static EDIT *remedit _((EDIT *));
-
 static EDIT *
-remedit(ep)
-	EDIT	*ep;		/* edit element to insert in front of */
+remedit(EDIT *ep)
 {	
 	EDIT	*np;		/* next edit structure in list */
 
@@ -278,10 +253,8 @@ remedit(ep)
  * of interactions of deleting, inserting, and copying from the source.
  */
 
-static void mergelists _((void));
-
 static void
-mergelists()
+mergelists(void)
 {
 	EDIT	*op;		/* pointer to current old edit structure */
 	EDIT	*np;		/* pointer to current new edit structure */
@@ -423,12 +396,8 @@ mergelists()
  * edit sequence read and checked.
  */
 
-static void readedits _((FILE *fp, long editnum));
-
 static void
-readedits(fp, editnumber)
-	FILE	*fp;		/* history file */
-	long	editnumber;	/* edit number */
+readedits(FILE *fp, long editnumber)
 {
 	char	*cp;		/* line of data */
 	long	filenumber;	/* file number containing whole edit */
@@ -593,15 +562,11 @@ readedits(fp, editnumber)
  * The output files are text, by definition.
  */
 
-static void writefile _((char *outputname, INFO *info));
-
 static void
-writefile(outputname, info)
-	char	*outputname;	/* name of output file */
-	INFO	*info;		/* edit information */
+writefile(const char *outputname, INFO *info)
 {
 	FILE	*sf;		/* source file */
-	FILE	*of;		/* output file */
+	output_ty *of;		/* output file */
 	EDIT	*ep;		/* current edit */
 	long	line;		/* current line number in source file */
 	long	count;
@@ -610,7 +575,13 @@ writefile(outputname, info)
 
 	line = 0;
 	sf = opensourcefile();
-	of = fopen_and_check(outputname, "w");
+	if (fc.binary)
+	{
+		of = output_file_binary_open(outputname);
+		of = output_quoted_printable_decode(of, 1);
+	}
+	else
+		of = output_file_text_open(outputname);
 
 	/*
 	 * Loop over each of the edit structures applying them to the
@@ -642,7 +613,7 @@ writefile(outputname, info)
 			sc.linelen = ep->e_textlen;
 			if (++line <= sc.modifylines)
 				cp = modifyline(cp, &sc.linelen, info);
-			writefx(of, cp, sc.linelen, outputname);
+			output_write(of, cp, sc.linelen);
 			continue;
 		}
 
@@ -658,15 +629,20 @@ writefile(outputname, info)
 			{
 				if (ep != &edittail)
 					fatal_intl(0, i18n("premature end of file"));
-				fflush_and_check(of, outputname);
-				fclose_and_check(of, outputname);
+				output_delete(of);
 				return;
 			}
 			if (bin)
+			{
+				/*
+				 * Because all should be encoded using
+				 * quoted printable.
+				 */
 				binary_fatal(sc.sourcename);
+			}
 			if (++line <= sc.modifylines)
 				cp = modifyline(cp, &sc.linelen, info);
-			writefx(of, cp, sc.linelen, outputname);
+			output_write(of, cp, sc.linelen);
 		}
 	}
 	fatal_intl(0, i18n("unexpected end of edit list"));
@@ -683,12 +659,8 @@ writefile(outputname, info)
  * The output files are text, by definition.
  */
 
-static void copyfile _((char *outputname, INFO *info));
-
 static void
-copyfile(outputname, info)
-	char	*outputname;	/* name of output file */
-	INFO	*info;		/* edit information */
+copyfile(const char *outputname, INFO *info)
 {
 	FILE	*sf;		/* source file for copying */
 	output_ty *of;		/* output file for copying */
@@ -698,32 +670,20 @@ copyfile(outputname, info)
 	int	bin;		/* IGNORED */
 
 	sf = opensourcefile();
-	if (outputname)
+	if (fc.binary)
 	{
-		if (fc.binary)
-			of = output_file_binary_open(outputname);
-		else
-			of = output_file_text_open(outputname);
+		of = output_file_binary_open(outputname);
+		of = output_quoted_printable_decode(of, 1);
 	}
 	else
-	{
-		of = output_stdout();
-	}
-	if (fc.binary)
-		of = output_quoted_printable_decode(of);
-	for (line = 0; line < sc.modifylines; line++)
-	{
-		cp = readlinef(sf, &linelen, 0, sc.sourcename, &bin);
-		if (cp == NULL)
-			break;
-		cp = modifyline(cp, &linelen, info);
-		output_write(of, cp, linelen);
-	}
-	for (;;)
+		of = output_file_text_open(outputname);
+	for (line = 0; ; ++line)
 	{
 		cp = readlinef(sf, &linelen, 0, sc.sourcename, &bin);
 		if (cp == NULL)
 			break;
+		if (line < sc.modifylines)
+		    cp = modifyline(cp, &linelen, info);
 		output_write(of, cp, linelen);
 	}
 	output_delete(of);
@@ -736,10 +696,7 @@ copyfile(outputname, info)
  */
 
 void
-extracthistory(editname, outputname, blabflag)
-	char	*editname;	/* edit string (NULL for current) */
-	char	*outputname;	/* output file for extract (NULL if tty) */
-	int	blabflag;	/* non-zero if describe file being extracted */
+extracthistory(char *editname, char *outputname, int blabflag)
 {
 	char	*str;		/* string being manipulated */
 	long	editnumber;	/* edit number being extracted */
@@ -911,7 +868,7 @@ i18n("extracting latest edit $number of module \"$module\" to file \"$filename\"
  */
 
 void
-editreset()
+editreset(void)
 {
 	editfreelist = NULL;
 	editnewbegin = NULL;
