@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -41,15 +41,8 @@
  * The information is written to the usual output file.
  */
 
-static void listone _((FILE *fp, long edit, POS *pp, FILE *of, const char *ofn));
-
 static void
-listone(fp, edit, pp, of, ofn)
-	FILE		*fp;		/* edit history file */
-	long		edit;		/* edit number */
-	POS		*pp;		/* position structure for edit */
-	FILE		*of;		/* output file */
-	const char	*ofn;
+listone(FILE *fp, long edit, POS *pp, FILE *of, const char *ofn)
 {
 	char		*cp;		/* current line */
 	long		tempedit;	/* edit number */
@@ -117,10 +110,7 @@ listone(fp, edit, pp, of, ofn)
  */
 
 void
-listhistory(editname1, editname2, outputname)
-	char	*editname1;	/* first edit name (NULL if none) */
-	char	*editname2;	/* second edit name (NULL if none) */
-	char	*outputname;	/* output file name (NULL if tty) */
+listhistory(char *editname1, char *editname2, char *outputname)
 {
 	FILE	*fp;		/* history file */
 	FILE	*of;		/* output file */
