@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void namehistory _((char *editname));
-void checkeditname _((char *editname));
+void namehistory(char *editname);
+void checkeditname(char *editname);
 
 #endif /* NAME_H */
