@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 2000 Peter Miller;
+ *	Copyright (C) 1991-1995, 1997, 1998, 2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -23,8 +23,8 @@
  * MANIFEST: operating system entry point, and parse arguments
  */
 
-#include <ac/stdio.h>
 #include <ac/errno.h>
+#include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 
@@ -35,6 +35,7 @@
 #include <fileio.h>
 #include <help.h>
 #include <progname.h>
+#include <quit.h>
 #include <version.h>
 #include <work.h>
 
@@ -65,10 +66,8 @@ static arglex_table_ty argtab[] =
 };
 
 
-static void usage _((void));
-
 static void
-usage()
+usage(void)
 {
 	char		*progname;
 
@@ -76,14 +75,12 @@ usage()
 	fprintf(stderr, "usage: %s [ <option>... ] <basefile> <file1> <file2>\n", progname);
 	fprintf(stderr, "       %s -Help\n", progname);
 	fprintf(stderr, "       %s -VERSion\n", progname);
-	exit(1);
+	quit(1);
 }
 
 
-static void main_help _((void));
-
 static void
-main_help()
+main_help(void)
 {
 	help(NULL, usage);
 }
@@ -95,11 +92,8 @@ main_help()
  * or returns copied value of global variable.
  */
 
-static char *expand _((char *));
-
 static char *
-expand(cp)
-	char		*cp;	/* string to be checked */
+expand(char *cp)
 {
 	char		*var;	/* variable value */
 
@@ -118,15 +112,11 @@ expand(cp)
  * This is the main program.
  */
 
-int main _((int, char **));
-
 int
-main(argc, argv)
-	int		argc;
-	char		**argv;
+main(int argc, char **argv)
 {
 	char		*cp;		/* current option character */
-	char		*basename;	/* file which is the base file */
+	char		*base_name;	/* file which is the base file */
 	char		*nameA;
 	char		*nameB;		/* the two divergent files */
 	char		*ofile;		/* output merged filename */
@@ -139,16 +129,16 @@ main(argc, argv)
 	{
 	case arglex_token_help:
 		main_help();
-		exit(0);
+		quit(0);
 
 	case arglex_token_version:
 		version();
-		exit(0);
+		quit(0);
 
 	default:
 		break;
 	}
-	basename = NULL;
+	base_name = NULL;
 	nameA = NULL;
 	nameB = NULL;
 	ofile = NULL;
@@ -173,8 +163,8 @@ main(argc, argv)
 			/* a file name */
 			cp = expand(arglex_value.alv_string);
 			filecount++;
-			if (!basename)
-				basename = cp;
+			if (!base_name)
+				base_name = cp;
 			else if (!nameA)
 				nameA = cp;
 			else if (!nameB)
@@ -288,14 +278,14 @@ main(argc, argv)
 		/* converting conflict file */
 		if (conflictflag)
 			fatal_intl(0, i18n("conflicting options for conflict file conversion"));
-		convertconflicts(basename, ofile);
-		exit(0);
+		convertconflicts(base_name, ofile);
+		quit(0);
 	}
 	if (filecount != 3)
 		fatal_intl(0, i18n("must have three input files for merge"));
 	if (!outputflag && !conflictflag)
 		outputflag = 1;
-	fmerge(basename, nameA, nameB);
+	fmerge(base_name, nameA, nameB);
 	if (outputflag)
 		dumpmergedfile(ofile);
 	if (conflictflag)
@@ -321,6 +311,6 @@ main(argc, argv)
 		);
 		sub_context_delete(scp);
 	}
-	exit(0);
+	quit(0);
 	return 0;
 }
