@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1991-1994, 1997-2000, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -80,10 +80,8 @@ static	LINE	**fileBlines;	/* lines of file B */
  * Allocate a new merge structure and append it to the end of the merge list.
  */
 
-static MERGE *newmerge _((void));
-
 static MERGE *
-newmerge()
+newmerge(void)
 {
 	MERGE	*mp;		/* new merge structure */
 
@@ -112,10 +110,7 @@ newmerge()
  */
 
 void
-fmerge(basename, nameA, nameB)
-	char	*basename;	/* original file for both edits */
-	char	*nameA;		/* file containing first set of changes */
-	char	*nameB;		/* file containing second set of changes */
+fmerge(char *basename, char *nameA, char *nameB)
 {
 	SNAKE	*spA;		/* snake for edits of first file */
 	SNAKE	*spB;		/* snake for edits of second file */
@@ -413,8 +408,7 @@ fmerge(basename, nameA, nameB)
  */
 
 void
-dumpmergedfile(outputname)
-	char	*outputname;	/* output file name */
+dumpmergedfile(char *outputname)
 {
 	MERGE	*mp;		/* current merge structure */
 	LINE	**lp;		/* current line */
@@ -489,15 +483,8 @@ dumpmergedfile(outputname)
  * structure not processed due to the change of conflict.
  */
 
-static MERGE *walkmerges _((FILE *fp, MERGE *mp, int flagmask,
-	const char *filename));
-
 static MERGE *
-walkmerges(fp, mp, flagmask, filename)
-	FILE		*fp;		/* file to output to */
-	MERGE		*mp;		/* starting point to dump */
-	int		flagmask;
-	const char	*filename;
+walkmerges(FILE *fp, MERGE *mp, int flagmask, const char *filename)
 {
 	LINE		**lp;		/* current line */
 	short		count;		/* number of lines to handle */
@@ -589,8 +576,7 @@ walkmerges(fp, mp, flagmask, filename)
  */
 
 void
-dumpconflicts(outputname)
-	char	*outputname;	/* output file name */
+dumpconflicts(char *outputname)
 {
 	MERGE	*mp;		/* current merge structure */
 	FILE	*fp;		/* file to output to */
@@ -638,9 +624,7 @@ dumpconflicts(outputname)
  */
 
 void
-convertconflicts(inputname, outputname)
-	char		*inputname;	/* conflict file being read */
-	char		*outputname;	/* output file (or NULL for terminal) */
+convertconflicts(char *inputname, char *outputname)
 {
 	char		*cp;		/* current line */
 	FILE		*ip;		/* input file */
