@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1993, 1994, 1998 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,9 +30,9 @@ extern long failcount;		/* maximum conflicts allowable */
 extern long unchangecount;	/* maximum unchanged lines to output */
 extern short ignoreflag;	/* ignore conflicts */
 
-void fmerge _((char *base_name, char *nameA, char *nameB));
-void dumpmergedfile _((char *outname));
-void dumpconflicts _((char *outname));
-void convertconflicts _((char *inname, char *outname));
+void fmerge(char *base_name, char *nameA, char *nameB);
+void dumpmergedfile(char *outname);
+void dumpconflicts(char *outname);
+void convertconflicts(char *inname, char *outname);
 
 #endif /* WORK_H */
