@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	fhist - file history and comparison tools
-#	Copyright (C) 1993, 1994, 1998, 2000 Peter Miller;
+#	Copyright (C) 1993, 1994, 1998, 2000, 2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,10 @@
 work=/tmp/$$
 PAGER=cat
 export PAGER
+LINES=24
+export LINES
+COLS=80
+export COLS
 
 fail()
 {
